@@ -37,26 +37,26 @@ static int triangular_inverse_L2(CBLAS_UPLO_t Uplo, CBLAS_DIAG_t Diag, gsl_matri
 static int triangular_inverse_L3(CBLAS_UPLO_t Uplo, CBLAS_DIAG_t Diag, gsl_matrix * T);
 static int triangular_singular(const gsl_matrix * T);
 
-int
-gsl_linalg_tri_invert(CBLAS_UPLO_t Uplo, CBLAS_DIAG_t Diag, gsl_matrix * T)
-{
-  const size_t N = T->size1;
-
-  if (N != T->size2)
-    {
-      GSL_ERROR ("matrix must be square", GSL_ENOTSQR);
-    }
-  else
-    {
-      int status;
-
-      status = triangular_singular(T);
-      if (status)
-        return status;
-
-      return triangular_inverse_L3(Uplo, Diag, T);
-    }
-}
+// int
+// gsl_linalg_tri_invert(CBLAS_UPLO_t Uplo, CBLAS_DIAG_t Diag, gsl_matrix * T)
+// {
+//   const size_t N = T->size1;
+//
+//   if (N != T->size2)
+//     {
+//       GSL_ERROR ("matrix must be square", GSL_ENOTSQR);
+//     }
+//   else
+//     {
+//       int status;
+//
+//       status = triangular_singular(T);
+//       if (status)
+//         return status;
+//
+//       return triangular_inverse_L3(Uplo, Diag, T);
+//     }
+// }
 
 /*
 triangular_inverse_L2()
@@ -263,4 +263,3 @@ gsl_linalg_tri_lower_invert_dings(gsl_matrix* T)
 
 
 #endif
-
